import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { TableApiService } from 'src/app/_services/table-api.service';

@Component({
  selector: 'app-cost-management',
  templateUrl: './cost-management.component.html',
  styleUrls: ['./cost-management.component.css']
})
export class CostManagementComponent implements OnInit{
  public breadcrumb: any;
  data: any;
  filteredRows: any[];
  searchTerm: string = "";
  rows: any = [];

  donutChart1: any;
  donutChart2: any;
  dataChart = {
    donut: {
      series: [50, 50],
      labels: [],
    },
  };
  dataChart2 = {
    donut: {
      series: [50, 50],
      labels: [],
    },
  };

  barChart: any;
  dataBar = {
    "Bar": {
      "labels": [],
      "series": [
        [
          80,
          60
        ]
      ]
    },
  }

  constructor(
    private tableApiservice: TableApiService,
    private router: Router
  ) {}

  ngOnInit() {
    this.breadcrumb = {
      mainlabel: "Cost Management",
      links: [
        {
          name: "Home",
          isLink: false,
        },
        {
          name: "Cost Management",
          isLink: false,
        },
      ],
    };
    this.fetchData();

    this.barChart = {
      type: 'Bar',
      data: this.dataBar.Bar,
      options: {
        fullwidth: true,
        axisX: {
          showGrid: false,
          showLabel: false,
          offset: 100
        },
  
        axisY: {
          showGrid: false,
          showLabel: false
        }
      }
    };

    this.donutChart1 = {
      type: "Pie",
      data: this.dataChart.donut,
      options: {
        fullwidth: true,
        height: "300px",
        donut: true,
        donutWidth: 70,
        startAngle: 270,
        total: 200,
        showLabel: true,
      },
    };
    this.donutChart2 = {
      type: "Pie",
      data: this.dataChart2.donut,
      options: {
        chartPadding: 0,
        fullwidth: true,
        height: "150px",
        donut: true,
        showLabel: true,
        startAngle: 0,
        labelInterpolationFnc: function (value) {
          const total = 82;
          return total + "C";
        },
      },
      events: {
        draw(data: any): void {
          if (data.type === "label") {
            if (data.index === 0) {
              data.element.attr({
                dx: data.element.root().width() / 2,
                dy: data.element.root().height() / 2,
              });
            } else {
              data.element.remove();
            }
          }
        },
      },
    };
  }

  fetchData() {
    this.tableApiservice.getTableInitialisationData().subscribe((response) => {
      this.data = response;
      this.filteredRows = this.data.rows;
    });
  }

  filterRows() {
    if (!this.searchTerm) {
      this.filteredRows = [...this.data.rows];
    } else {
      this.filteredRows = this.data.rows.filter((row) =>
        this.rowContainsSearchTerm(row)
      );
    }
  }

  rowContainsSearchTerm(row: any): boolean {
    const searchTermLC = this.searchTerm.toLowerCase();
    return Object.values(row).some(
      (value) =>
        value !== null &&
        value.toString().toLowerCase().includes(searchTermLC)
    );
  }

  viewRow(row) {
    console.log("View row:", row);
    this.router.navigate(["/cost-management/view", row.name]);
  }

  editRow(row) {
    console.log("Edit row:", row);
    this.router.navigate(["/cost-management/edit", row.name]);
  }

  deleteRow(row) {
    console.log("Delete row:", row);
  }

  onTouchStart(event: Event) {
    event.preventDefault(); // Add this if necessary
  }
}
